Exposure to noise is prevented or controlled. | OiRA

Help

1. Προετοιμασία
2. Συμμετοχή των εργαζομένων
3. Αναγνώριση + Αξιολόγηση
   1. 1 Commercial manned guarding
      1. 1.1 Work environment (site related)
         1. 1.1.1 Slips, trips and falls are prevented.
         2. 1.1.2 Collisions, bumps, and jamming are prevented.
         3. 1.1.3 The electricity, gas and water supplies are in order and well-maintained.
         4. 1.1.4 Exposure to noise is prevented or controlled.
         5. 1.1.5 Exposure to chemical substances is prevented or controlled.
         6. 1.1.6 Exposure to biological substances is prevented or controlled.
         7. 1.1.7 Exposure to radiation is prevented or controlled.
         8. 1.1.8 Risks from ambient factors are prevented.
         9. 1.1.9 All necessary facilities are available and well maintained.
      2. 1.2 Fire prevention and emergency procedures
   2. Ω Πρόσθετοι κίνδυνοι (από το χρήστη)
   - Υπό εξέταση κίνδυνος
   - Κίνδυνος σε εκκρεμότητα
   - Ασφαλής κατάσταση
   - Προσοχή κίνδυνος!
4. Σχέδιο Δράσης
5. Έκθεση
6. Παρούσα Κατάσταση 0%

Help

## Exposure to noise is prevented or controlled.

Ναι Όχι Δεν ισχύει

### Πληροφορίες

Noise is an unwanted sound.

- Possible sources: noise of the building’s installations, of machinery, of office equipment, detonation of ammunition during shooting practice, noise by human beings, crowds, …
- Noise can cause considerable hearing damage. The intensity (loudness) and exposure duration determine whether noise is hazardous. Rule of thumb: ‘private security guards should be able to hear each other at one metre distance without raising their voice’.
- Noise can also be a source of annoyance and disturbance, if it interferes with the job or if the job is very complex.

**Make sure the client informs you (security company) and the private security guards **about the risks and measures in place.

Check whether the client:

- Has identified the source(s) of the noise + limit or reduce noise at source.
- Ensures technical maintenance of workplaces, installations, …
- Provides work signs and PPEs.

Promotes working habits and behaviour that are not noisy.

### Πηγές Πληροφόρησης

#### Νομικές αναφορές και αναφορές πολιτικής

- 89/391/CEE Implementing measures to improve the health and safety of workers (framework directive).
- 89/654/EEC Directive on the minimum safety and health requirements for the workplace.
- 2003/10/EC Directive on the minimum health and safety requirements regarding the exposure of workers to the risks arising from physical agents (noise).

#### Πρόσθετο πληροφοριακό υλικό για την εκτίμηση του κινδύνου

- Lorem ipsum dolor sit.pdf
- Amet consectetuer.pdf

Σχόλια / Υφιστάμενα μέτρα (αν υπάρχουν)

Scroll to top
Back

## 2014-01-06-exposure-to-noise-is-prevented-or-controlled.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More